translate.convert.po2oo.reoo

Package translate :: Package convert :: Module po2oo :: Class reoo |
[hide private]
[frames] | no frames]

# Class reoo

source code

Instance Methods | [hide private]
__init__(self, templatefile, languages=None, timestamp=None, includefuzzy=False, long_keys=False, filteraction=`'``exclude``'`) construct a reoo converter for the specified languages (timestamp=0 means leave unchanged) | source code
makeindex(self) makes an index of the oo keys that are used in the source file | source code
readoo(self, of) read in the oo from the file | source code
handleunit(self, unit) | source code
applytranslation(self, key, subkey, theoo, unit) applies the translation from the source unit to the oo unit | source code
convertstore(self, sourcestore) | source code